[Scummvm-cvs-logs] SF.net SVN: scummvm: [32331] scummvm/trunk/backends/platform/sdl/sdl.cpp

lordhoto at users.sourceforge.net lordhoto at users.sourceforge.net
Tue May 27 23:18:22 CEST 2008


Revision: 32331
          http://scummvm.svn.sourceforge.net/scummvm/?rev=32331&view=rev
Author:   lordhoto
Date:     2008-05-27 14:18:21 -0700 (Tue, 27 May 2008)

Log Message:
-----------
Fixed choppy sound on my Vista box. (after talking with Fingolfin about it)

Modified Paths:
--------------
    scummvm/trunk/backends/platform/sdl/sdl.cpp

Modified: scummvm/trunk/backends/platform/sdl/sdl.cpp
===================================================================
--- scummvm/trunk/backends/platform/sdl/sdl.cpp	2008-05-27 21:04:27 UTC (rev 32330)
+++ scummvm/trunk/backends/platform/sdl/sdl.cpp	2008-05-27 21:18:21 UTC (rev 32331)
@@ -403,10 +403,10 @@
 		_samplesPerSec = SAMPLES_PER_SEC;
 
 	// Determine the sample buffer size. We want it to store enough data for
 	// about 1/64th of a second. Note that it must be a power of two.
 	// So e.g. at 22050 Hz, we request a sample buffer size of 2048.
 	int samples = 8192;
-	while (64 * samples >= _samplesPerSec) {
+	while (32 * samples >= _samplesPerSec) {
 		samples >>= 1;
 	}
 
@@ -403,10 +403,10 @@
 
 	// Determine the sample buffer size. We want it to store enough data for
-	// about 1/64th of a second. Note that it must be a power of two.
+	// about 1/32th of a second. Note that it must be a power of two.
 	// So e.g. at 22050 Hz, we request a sample buffer size of 2048.
 	int samples = 8192;


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list